pub type Dec32 = Decimal<u32, true>;
The 32-bit decimal type, with about 9 significant digits and at most 7 fraction digits.
Since cargo generates full documentation only for the first alias (Dec128), here is almost empty. See the Decimal page for full documentation of this alias.
Dec128
Decimal
pub struct Dec32(/* private fields */);